@@ -8,7 +8,8 @@ from sql.aggregate import Sum
 from sql.conditionals import Coalesce
 
 from trytond import backend
-from trytond.model import ModelView, ModelSQL, fields, Unique
+from trytond.model import (ModelView, ModelSQL, DeactivableMixin, fields,
+    Unique, tree)
 from trytond.wizard import Wizard, StateView, StateAction, Button
 from trytond.pyson import Eval, If, PYSONEncoder, PYSONDecoder
 from trytond.transaction import Transaction
@@ -19,12 +20,13 @@ __all__ = ['Account', 'AccountDistribution',
     'AnalyticAccountEntry', 'AnalyticMixin']
 
 
-class Account(ModelSQL, ModelView):
+class Account(
+        DeactivableMixin, tree('distribution_parents'), tree(),
+        ModelSQL, ModelView):
     'Analytic Account'
     __name__ = 'analytic_account.account'
     name = fields.Char('Name', required=True, translate=True, select=True)
     code = fields.Char('Code', select=True)
-    active = fields.Boolean('Active', select=True)
     company = fields.Many2One('company.company', 'Company', required=True)
     currency = fields.Function(
         fields.Many2One('currency.currency', 'Currency'),
@@ -110,22 +112,17 @@ class Account(ModelSQL, ModelView):
         cls._error_messages.update({
                 'invalid_distribution': (
                     'The distribution sum of account "%(account)s" '
-                    'is not 100%.'),
+                    'is not 100%%.'),
                 })
 
     @classmethod
     def __register__(cls, module_name):
-        TableHandler = backend.get('TableHandler')
         super(Account, cls).__register__(module_name)
-        table = TableHandler(cls, module_name)
+        table = cls.__table_handler__(module_name)
 
         # Migration from 4.0: remove currency
         table.not_null_action('currency', action='remove')
 
-    @staticmethod
-    def default_active():
-        return True
-
     @staticmethod
     def default_company():
         return Transaction().context.get('company')
@@ -149,8 +146,6 @@ class Account(ModelSQL, ModelView):
     @classmethod
     def validate(cls, accounts):
         super(Account, cls).validate(accounts)
-        cls.check_recursion(accounts)
-        cls.check_recursion(accounts, parent='distribution_parents')
         for account in accounts:
             account.check_distribution()
 
@@ -196,7 +191,7 @@ class Account(ModelSQL, ModelView):
 
         ids = [a.id for a in accounts]
         childs = cls.search([('parent', 'child_of', ids)])
-        all_ids = {}.fromkeys(ids + [c.id for c in childs]).keys()
+        all_ids = list({}.fromkeys(ids + [c.id for c in childs]).keys())
 
         id2account = {}
         all_accounts = cls.browse(all_ids)
@@ -232,7 +227,8 @@ class Account(ModelSQL, ModelView):
                 balance += account_sum[child.id]
             if account.display_balance == 'credit-debit' and balance:
                 balance *= -1
-            balances[account.id] = account.currency.round(balance)
+            exp = Decimal(str(10.0 ** -account.currency_digits))
+            balances[account.id] = balance.quantize(exp)
         return balances
 
     @classmethod
@@ -280,15 +276,16 @@ class Account(ModelSQL, ModelView):
                 result[name][account_id] += value
         for account in accounts:
             for name in names:
-                result[name][account.id] = account.currency.round(
-                    result[name][account.id])
+                exp = Decimal(str(10.0 ** -account.currency_digits))
+                result[name][account.id] = (
+                    result[name][account.id].quantize(exp))
         return result
 
     def get_rec_name(self, name):
         if self.code:
-            return self.code + ' - ' + unicode(self.name)
+            return self.code + ' - ' + str(self.name)
         else:
-            return unicode(self.name)
+            return str(self.name)
 
     @classmethod
     def search_rec_name(cls, name, clause):
@@ -426,7 +423,7 @@ class AnalyticAccountEntry(ModelView, ModelSQL):
             migration_3_4 = True
 
         # Don't create table before renaming
-        table = TableHandler(cls, module_name)
+        table = cls.__table_handler__(module_name)
 
         super(AnalyticAccountEntry, cls).__register__(module_name)
 
@@ -517,12 +514,11 @@ class AnalyticMixin(object):
     def __register__(cls, module_name):
         pool = Pool()
         AccountEntry = pool.get('analytic.account.entry')
-        TableHandler = backend.get('TableHandler')
         cursor = Transaction().connection.cursor()
 
         super(AnalyticMixin, cls).__register__(module_name)
 
-        handler = TableHandler(cls, module_name)
+        handler = cls.__table_handler__(module_name)
         # Migration from 3.4: analytic accounting changed to reference field
         if handler.column_exist('analytic_accounts'):
             entry = AccountEntry.__table__()
