@@ -7,7 +7,6 @@ from sql import Literal
 
 from trytond.model import ModelView, ModelSQL, fields, Check
 from trytond.wizard import Wizard, StateAction
-from trytond import backend
 from trytond.pyson import Eval, PYSONEncoder
 from trytond.transaction import Transaction
 from trytond.pool import Pool, PoolMeta
@@ -60,12 +59,8 @@ class Line(ModelSQL, ModelView):
 
     @classmethod
     def __register__(cls, module_name):
-        TableHandler = backend.get('TableHandler')
         super(Line, cls).__register__(module_name)
-        table = TableHandler(cls, module_name)
-
-        # Migration from 1.2 currency has been changed in function field
-        table.not_null_action('currency', action='remove')
+        table = cls.__table_handler__(module_name)
 
         # Migration from 4.0: remove name and journal
         for field_name in ['name', 'journal']:
@@ -164,8 +159,7 @@ class Line(ModelSQL, ModelView):
                 (self.account.rec_name,))
 
 
-class Move:
-    __metaclass__ = PoolMeta
+class Move(metaclass=PoolMeta):
     __name__ = 'account.move'
 
     @classmethod
@@ -210,8 +204,7 @@ class MoveLine(ModelSQL, ModelView):
 
     @classmethod
     def __register__(cls, module_name):
-        TableHandler = backend.get('TableHandler')
-        table = TableHandler(cls, module_name)
+        table = cls.__table_handler__(module_name)
         cursor = Transaction().connection.cursor()
         sql_table = cls.__table__()
 
@@ -289,11 +282,11 @@ class MoveLine(ModelSQL, ModelView):
             for analytic_line in line.analytic_lines:
                 amount = analytic_line.debit - analytic_line.credit
                 amounts[analytic_line.account.root] += amount
-            if not roots <= set(amounts.iterkeys()):
+            if not roots <= set(amounts.keys()):
                 line.analytic_state = 'draft'
                 continue
             amount = line.debit - line.credit
-            for analytic_amount in amounts.itervalues():
+            for analytic_amount in amounts.values():
                 if analytic_amount != amount:
                     line.analytic_state = 'draft'
                     break
